diff src/main/java/org/monetdb/mcl/io/BufferedMCLReader.java @ 391:f523727db392

Moved Java classes from packages starting with nl.cwi.monetdb.* to package org.monetdb.* This naming complies to the Java Package Naming convention as MonetDB's main website is www.monetdb.org.
author Martin van Dinther <martin.van.dinther@monetdbsolutions.com>
date Thu, 12 Nov 2020 22:02:01 +0100 (2020-11-12)
parents src/main/java/nl/cwi/monetdb/mcl/io/BufferedMCLReader.java@54137aeb1f92
children bf9f6b6ecf40
line wrap: on
line diff
copy from src/main/java/nl/cwi/monetdb/mcl/io/BufferedMCLReader.java
copy to src/main/java/org/monetdb/mcl/io/BufferedMCLReader.java
--- a/src/main/java/nl/cwi/monetdb/mcl/io/BufferedMCLReader.java
+++ b/src/main/java/org/monetdb/mcl/io/BufferedMCLReader.java
@@ -6,7 +6,7 @@
  * Copyright 1997 - July 2008 CWI, August 2008 - 2020 MonetDB B.V.
  */
 
-package nl.cwi.monetdb.mcl.io;
+package org.monetdb.mcl.io;
 
 import java.io.BufferedReader;
 import java.io.IOException;
@@ -31,14 +31,14 @@ import java.io.UnsupportedEncodingExcept
  * data from the stream in a linewise fashion, whereby each line is
  * identified as a certain type, consumers can easily decide how to
  * parse each retrieved line.  The line parsers from
  * nl.cwi.monetdb.mcl.parser are well suited to work with the lines
  * outputted by the BufferedMCLReader.
  * This class is client-oriented, as it doesn't take into account the
  * messages as the server receives them.
  *
  * @author Fabian Groffen
- * @see nl.cwi.monetdb.mcl.net.MapiSocket
- * @see nl.cwi.monetdb.mcl.io.BufferedMCLWriter
+ * @see org.monetdb.mcl.net.MapiSocket
+ * @see org.monetdb.mcl.io.BufferedMCLWriter
  */
 public final class BufferedMCLReader extends BufferedReader {
 	/** "there is currently no line", or the the type is unknown is represented by UNKNOWN */
@@ -112,7 +112,7 @@ public final class BufferedMCLReader ext
 		}
 		return r;
 	}
-	
+
 	/**
 	 * Sets the linetype to the type of the string given.  If the string
 	 * is null, lineType is set to UNKNOWN.
@@ -31,14 +31,14 @@ import java.io.UnsupportedEncodingExcept
  * identified as a certain type, consumers can easily decide how to
  * parse each retrieved line.  The line parsers from
- * nl.cwi.monetdb.mcl.parser are well suited to work with the lines
+ * org.monetdb.mcl.parser are well suited to work with the lines
  * outputted by the BufferedMCLReader.
  * This class is client-oriented, as it doesn't take into account the